@@ -19,11 +19,11 @@ def get_lxr_cookies() -> RequestsCookieJar:
     }
 
     data = {
-        "uniqueName": "murphyxiaoxi",
+        "accountName": "murphyxiaoxi",
         "password": "mofei6337"
     }
 
-    r = requests.post(url="https://www.lixinger.com/api/login/by-account", json=data, timeout=30,
+    r = requests.post(url="https://www.lixinger.com/api/account/sign-in/by-account", json=data, timeout=30,
                       verify=False)
     return r.cookies
 
@@ -386,10 +386,10 @@ def persist_monitor_data_hand():
 
 if __name__ == '__main__':
     p = LixinrenPersist()
-    # lxr_stock_id = 1000000399812
-    # index_code = '399812'
-    # index_name = '养老产业'
-    # p._persist_index_data(lxr_stock_id, index_code, index_name, '')
-    # merge = LxrMerge2Jsl()
-    # merge.merge(index_code)
-    p.persist_monitor_handler_data()
+    lxr_stock_id = 101000000006472
+    index_code = '.INX'
+    index_name = '标普500'
+    p._persist_index_data(lxr_stock_id, index_code, index_name, '')
+    merge = LxrMerge2Jsl()
+    merge.merge(index_code)
+    # p.persist_monitor_handler_data()
