@@ -2,15 +2,15 @@ import pymysql
 
 
 class EtfTrackConfig:
-    def __init__(self, etf_code: str, etf_name, index_code: str, index_name: str = '', strategy = '',
-                 track_days: int = 20*252,
+    def __init__(self, etf_code: str, etf_name, index_code: str, index_name: str = '', is_pe=1,
+                 track_days: int = 20 * 252,
                  low_percent: float = 0.25, high_percent: float = 0.75,
                  std_low_weight: float = 2, std_high_weight: float = 2):
         self.etf_code = etf_code
         self.etf_name = etf_name
         self.index_code = index_code
         self.index_name = index_name
-        self.strategy = strategy
+        self.is_pe = is_pe
         self.track_days = track_days
         self.low_percent = low_percent
         self.high_percent = high_percent
@@ -23,7 +23,7 @@ class EtfTrackConfig:
 
         conn = pymysql.connect(user='root', password='', database='quant', charset='utf8')
         cursor = conn.cursor()
-        sql = "select etf_code, etf_name, index_id, index_name, strategy from jsl_etf_list where monitor = 1 "
+        sql = "select etf_code, etf_name, index_id, index_name, is_pe from jsl_etf_list where monitor = 1 "
         cursor.execute(sql)
         conn.commit()
 
@@ -32,9 +32,9 @@ class EtfTrackConfig:
             etf_name = item[1]
             index_id = item[2]
             index_name = item[3]
-            strategy = item[4]
+            is_pe = item[4]
 
-            configs.append(EtfTrackConfig(etf_code, etf_name, index_id, index_name, strategy))
+            configs.append(EtfTrackConfig(etf_code, etf_name, index_id, index_name, is_pe))
 
         return configs
 
