@@ -113,10 +113,7 @@ class IndexMonitor:
             pe_less_prob_10y.append(int(round(stat.pe_less_prob_10y)))
             pe_less_prob_10y_2m_ago.append(int(round(stat.pe_less_prob_10y_2m_ago)))
             # pe_diff_2m_ago_signal.append(self.pe_cur_ago_signal(stat.pe_latest, stat.pe_2m_ago))
-            if stat.is_pe == 1:
-                pe_percent_signal.append(self.pe_percent_signal(stat.pe_less_prob_10y))
-            else:
-                pe_percent_signal.append(self.pe_percent_signal(stat.pb_less_prob_10y))
+            pe_percent_signal.append(self.pe_percent_signal(stat.pe_less_prob_10y))
 
             pe_mean_div_rt.append(round(stat.pe_latest / stat.pe_mean_10y, 2))
             pe_max_rt.append(round(stat.pe_latest / stat.pe_max, 2))
